<?php
/**
 * Add custom settings and controls to the WordPress Customizer
 */


//---------------------Code to add the Upgrade to Pro button in the Customizer----------

function urban_restaurant_customize_register_btn( $wp_customize ) {
    $wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

    get_template_part('inc/customizer-button/upsell-section');

    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'blogname', array(
            'selector'        => '.site-title a',
            'render_callback' => 'urban_restaurant_customize_partial_blogname',
        ) );
        $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
            'selector'        => '.site-description',
            'render_callback' => 'urban_restaurant_customize_partial_blogdescription',
        ) );
    }

    $wp_customize->register_section_type( 'Urban_Restaurant_Customize_Upsell_Section' );

    // Register section.
    $wp_customize->add_section(
        new Urban_Restaurant_Customize_Upsell_Section(
            $wp_customize,
            'theme_upsell',
            array(
                'title'    => esc_html__( 'Restaurant Pro', 'urban-restaurant' ),
                'pro_text' => esc_html__( 'Upgrade To Pro', 'urban-restaurant' ),
                'pro_url'  => 'https://cawpthemes.com/urban-restaurant-premium-wordpress-theme/',
                'priority' => 1,
            )
        )
    );
}
add_action( 'customize_register', 'urban_restaurant_customize_register_btn' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function urban_restaurant_customize_partial_blogname() {
    bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function urban_restaurant_customize_partial_blogdescription() {
    bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function urban_restaurant_customize_preview_js() {
    wp_enqueue_script( 'urban-restaurant-customizer', get_template_directory_uri() . '/inc/customizer-button/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'urban_restaurant_customize_preview_js' );

/**
 * Customizer control scripts and styles.
 *
 * @since 1.0.0
 */
function urban_restaurant_customizer_control_scripts() {

    wp_enqueue_style( 'urban-restaurant-customize-controls', get_template_directory_uri() . '/inc/customizer-button/customize-controls.css', '', '1.0.0' );

    wp_enqueue_script( 'urban-restaurant-customize-controls', get_template_directory_uri() . '/inc/customizer-button/customize-controls.js', array( 'customize-controls' ), '1.0.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'urban_restaurant_customizer_control_scripts', 0 );


//---------------------Code to add the Upgrade to Pro button in the Customizer End----------


//------------------Theme Information--------------------


function urban_restaurant_customize_register( $wp_customize ) {


      // Add a custom setting for the Site Identity color
  $wp_customize->add_setting( 'urban_restaurant_site_identity_color', array(
    'default' => '#a2191e',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );

  // Add a custom control for the primary color
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'urban_restaurant_site_identity_color', array(
    'label' => __( 'Site Identity Color', 'urban-restaurant' ),
    'section' => 'title_tagline',
    'settings' => 'urban_restaurant_site_identity_color',
  ) ) );


  // Add a custom setting for the Site Identity color
  $wp_customize->add_setting( 'urban_restaurant_site_identity_tagline_color', array(
    'default' => '#000',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );

  // Add a custom control for the primary color
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'urban_restaurant_site_identity_tagline_color', array(
    'label' => __( 'Tagline Color', 'urban-restaurant' ),
    'section' => 'title_tagline',
    'settings' => 'urban_restaurant_site_identity_tagline_color',
  ) ) );

//------------------Site Identity Ends---------------------

  
  // Add a custom setting for the primary color
  $wp_customize->add_setting( 'urban_restaurant_primary_color', array(
    'default' => '#0073aa',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );

  // Add a custom control for the primary color
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'urban_restaurant_primary_color', array(
    'label' => __( 'Primary Color', 'urban-restaurant' ),
    'section' => 'colors',
    'settings' => 'urban_restaurant_primary_color',
  ) ) );

  //-----------------------------------Home Front Page-------------------------------

  $wp_customize->add_panel( 'urban_restaurant_panel', array(
    'title'    => __( 'Front Page Settings', 'urban-restaurant' ),
    'priority' => 100,
  ) );


  //-------------------------------------Banner Image Section--------------

      $wp_customize->add_section( 'urban_restaurant_section_banner', array(
        'title'    => __( 'Home First Section', 'urban-restaurant' ),
        'priority' => 8,
        'panel'    => 'urban_restaurant_panel',
    ) );


  //-----------------Enable Option banner-------------

  $wp_customize->add_setting('urban_restaurant_section_banner',array(
      'default' => 'Enable',
      'sanitize_callback' => 'urban_restaurant_sanitize_choices'
  ));
  $wp_customize->add_control('urban_restaurant_section_banner',array(
        'type' => 'radio',
        'label' => __('Do you want this section', 'urban-restaurant'),
        'section' => 'urban_restaurant_section_banner',
        'choices' => array(
            'Enable' => __('Enable', 'urban-restaurant'),
            'Disable' => __('Disable', 'urban-restaurant')
  )));

  $wp_customize->add_setting('urban_restaurant_section_bannerimage_section',array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control(
    new WP_Customize_Image_Control( $wp_customize,'urban_restaurant_section_bannerimage_section',array(
    'label' => __('Section Background Image','urban-restaurant'),
    'description' => __('Dimention 1600 * 800','urban-restaurant'),
    'section' => 'urban_restaurant_section_banner',
    'settings' => 'urban_restaurant_section_bannerimage_section'
  )));

    $wp_customize->add_setting('urban_restaurant_section_bannerimage_section_title',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_section_bannerimage_section_title',array(
      'label' => __('Banner Title','urban-restaurant'),
      'section' => 'urban_restaurant_section_banner',
      'setting' => 'urban_restaurant_section_bannerimage_section_title',
      'type'    => 'text'
    )
  ); 

      $wp_customize->add_setting('urban_restaurant_section_bannerimage_section_text',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_section_bannerimage_section_text',array(
      'label' => __('Banner Text','urban-restaurant'),
      'section' => 'urban_restaurant_section_banner',
      'setting' => 'urban_restaurant_section_bannerimage_section_text',
      'type'    => 'text'
    )
  );

    $wp_customize->add_setting('urban_restaurant_banner_btn_text',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_banner_btn_text',array(
      'label' => __('Button Text','urban-restaurant'),
      'section' => 'urban_restaurant_section_banner',
      'setting' => 'urban_restaurant_banner_btn_text',
      'type'    => 'text'
    )
  );


    $wp_customize->add_setting('urban_restaurant_banner_btn_text_url',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_banner_btn_text_url',array(
      'label' => __('Button URL','urban-restaurant'),
      'section' => 'urban_restaurant_section_banner',
      'setting' => 'urban_restaurant_banner_btn_text_url',
      'type'    => 'text'
    )
  );


  //----------------------------------About Section----------------------------



    $wp_customize->add_section( 'urban_restaurant_about', array(
        'title'    => __( 'About Section', 'urban-restaurant' ),
        'priority' => 10,
        'panel'    => 'urban_restaurant_panel',
    ) );

  //-----------------Enable Option Section about-------------

  $wp_customize->add_setting('urban_restaurant_about_enable',array(
      'default' => 'Enable',
      'sanitize_callback' => 'urban_restaurant_sanitize_choices'
  ));
  $wp_customize->add_control('urban_restaurant_about_enable',array(
        'type' => 'radio',
        'label' => __('Do you want this section', 'urban-restaurant'),
        'section' => 'urban_restaurant_about',
        'choices' => array(
            'Enable' => __('Enable', 'urban-restaurant'),
            'Disable' => __('Disable', 'urban-restaurant')
  )));

  //-----------------------------About Image-----------

  $wp_customize->add_setting('urban_restaurant_aboutimage1_section',array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control(
    new WP_Customize_Image_Control( $wp_customize,'urban_restaurant_aboutimage1_section',array(
    'label' => __('About Side Image','urban-restaurant'),
    'description' => __('Dimention 500 * 750','urban-restaurant'),
    'section' => 'urban_restaurant_about',
    'settings' => 'urban_restaurant_aboutimage1_section'
  )));


    $wp_customize->add_setting('urban_restaurant_about_name',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_about_name',array(
      'label' => __('Main Heading','urban-restaurant'),
      'section' => 'urban_restaurant_about',
      'setting' => 'urban_restaurant_about_name',
      'type'    => 'text'
    )
  );


    $wp_customize->add_setting('urban_restaurant_about_title_second',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_about_title_second',array(
      'label' => __('Paragraph 1','urban-restaurant'),
      'section' => 'urban_restaurant_about',
      'setting' => 'urban_restaurant_about_title_second',
      'type'    => 'textarea'
    )
  );


    $wp_customize->add_setting('urban_restaurant_about_para',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_about_para',array(
      'label' => __('Paragraph 2','urban-restaurant'),
      'section' => 'urban_restaurant_about',
      'setting' => 'urban_restaurant_about_para',
      'type'    => 'textarea'
    )
  );

    $wp_customize->add_setting('urban_restaurant_about_btn_text',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_about_btn_text',array(
      'label' => __('Button Text','urban-restaurant'),
      'section' => 'urban_restaurant_about',
      'setting' => 'urban_restaurant_about_btn_text',
      'type'    => 'text'
    )
  );


    $wp_customize->add_setting('urban_restaurant_about_btn_text_url',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_about_btn_text_url',array(
      'label' => __('Button URL','urban-restaurant'),
      'section' => 'urban_restaurant_about',
      'setting' => 'urban_restaurant_about_btn_text_url',
      'type'    => 'text'
    )
  );

  //------------Features---------------------

  $wp_customize->add_section( 'urban_restaurant_features_amenities', array(
        'title'    => __( 'Details Section', 'urban-restaurant' ),
        'priority' => 10,
        'panel'    => 'urban_restaurant_panel',
    ) );


  //-----------------Enable Option Section One-------------

  $wp_customize->add_setting('urban_restaurant_features_enable',array(
      'default' => 'Enable',
      'sanitize_callback' => 'urban_restaurant_sanitize_choices'
  ));
  $wp_customize->add_control('urban_restaurant_features_enable',array(
        'type' => 'radio',
        'label' => __('Do you want this section', 'urban-restaurant'),
        'section' => 'urban_restaurant_features_amenities',
        'choices' => array(
            'Enable' => __('Enable', 'urban-restaurant'),
            'Disable' => __('Disable', 'urban-restaurant')
  )));


  //--------------------------- Details Image -----------

  $wp_customize->add_setting('urban_restaurant_featureimage1_section',array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control(
    new WP_Customize_Image_Control( $wp_customize,'urban_restaurant_featureimage1_section',array(
    'label' => __(' Details Image','urban-restaurant'),
    'description' => __('Dimention 600 * 450','urban-restaurant'),
    'section' => 'urban_restaurant_features_amenities',
    'settings' => 'urban_restaurant_featureimage1_section'
  )));


    $wp_customize->add_setting('urban_restaurant_feature1_title',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_feature1_title',array(
      'label' => __(' Details Title','urban-restaurant'),
      'section' => 'urban_restaurant_features_amenities',
      'setting' => 'urban_restaurant_feature1_title',
      'type'    => 'text'
    )
  ); 


    $wp_customize->add_setting('urban_restaurant_feature1_text',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_feature1_text',array(
      'label' => __('Details Text','urban-restaurant'),
      'section' => 'urban_restaurant_features_amenities',
      'setting' => 'urban_restaurant_feature1_text',
      'type'    => 'textarea'
    )
  ); 


  //------------Section One (Featured Post)---------------------

  $wp_customize->add_section( 'urban_restaurant_section1', array(
        'title'    => __( 'Latest Post', 'urban-restaurant' ),
        'priority' => 10,
        'panel'    => 'urban_restaurant_panel',
    ) );


  //-----------------Enable Option Section One-------------

  $wp_customize->add_setting('urban_restaurant_section1_enable',array(
      'default' => 'Enable',
      'sanitize_callback' => 'urban_restaurant_sanitize_choices'
  ));
  $wp_customize->add_control('urban_restaurant_section1_enable',array(
        'type' => 'radio',
        'label' => __('Do you want this section', 'urban-restaurant'),
        'section' => 'urban_restaurant_section1',
        'choices' => array(
            'Enable' => __('Enable', 'urban-restaurant'),
            'Disable' => __('Disable', 'urban-restaurant')
  )));

    //--------------Section One Title-----------------------

    $wp_customize->add_setting('urban_restaurant_section1_title',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
    )
  );
  $wp_customize->add_control('urban_restaurant_section1_title',array(
      'label' => __('Section Title','urban-restaurant'),
      'section' => 'urban_restaurant_section1',
      'setting' => 'urban_restaurant_section1_title',
      'type'    => 'text'
    )
  ); 

  //-----------Category------------

  $categories = get_categories();
  $cats = array();
  $i = 0;
  foreach($categories as $category){
    if($i==0){
      $default = $category->name;
      $i++;
    }
    $cats[$category->name] = $category->name;
  }

  $wp_customize->add_setting('urban_restaurant_section1_category',array(
  'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control('urban_restaurant_section1_category',array(
    'type'    => 'select',
    'choices' => $cats,
    'label' => __('Select Category to Display Post','urban-restaurant'),
    'section' => 'urban_restaurant_section1',
    'sanitize_callback' => 'sanitize_text_field',
  ));



    $wp_customize->add_setting('urban_restaurant_section1_category_number_of_posts_setting',array(
    'default' => '8',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('urban_restaurant_section1_category_number_of_posts_setting',array(
    'label' => __('Number of Posts','urban-restaurant'),
    'section' => 'urban_restaurant_section1',
    'setting' => 'urban_restaurant_section1_category_number_of_posts_setting',
    'type'    => 'number'
  )); 

  //-------------------------Footer Settings------------------------------


    $wp_customize->add_section( 'urban_restaurant_footer', array(
        'title'    => __( 'Footer Settings', 'urban-restaurant' ),
        'priority' => 10,
        'panel'    => 'urban_restaurant_panel',
    ) );


  // Add a custom setting for the footer text
  $wp_customize->add_setting( 'urban_restaurant_footer_text', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ) );

  // Add a custom control for the footer text
  $wp_customize->add_control( 'urban_restaurant_footer_text', array(
    'label' => __( 'Footer Text', 'urban-restaurant' ),
    'section' => 'urban_restaurant_footer',
    'type' => 'text',
  ) );


//--------------------------------------General Settings------------------------------------------

  $wp_customize->add_section( 'urban_restaurant_general', array(
        'title'    => __( 'General Settings', 'urban-restaurant' ),
        'panel'    => 'urban_restaurant_panel',
    ) );

    $wp_customize->add_setting( 'urban_restaurant_post_meta_toggle_switch_control', array(
        'default'   => true,
        'sanitize_callback' => 'sanitize_text_field', // Use a suitable sanitization function based on your needs
        'transport' => 'refresh', // or 'postMessage' for instant preview without page refresh
    ) );

    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'urban_restaurant_post_meta_toggle_switch_control', array(
        'label'    => __( 'Display Time/Author', 'urban-restaurant' ),
        'section'  => 'urban_restaurant_general',
        'settings' => 'urban_restaurant_post_meta_toggle_switch_control',
        'type'     => 'checkbox',
    ) ) );

    $wp_customize->add_setting( 'urban_restaurant_post_readdmore_toggle_switch_control', array(
        'default'   => true,
        'sanitize_callback' => 'sanitize_text_field', // Use a suitable sanitization function based on your needs
        'transport' => 'refresh', // or 'postMessage' for instant preview without page refresh
    ) );

    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'urban_restaurant_post_readdmore_toggle_switch_control', array(
        'label'    => __( 'Display Read More Link', 'urban-restaurant' ),
        'section'  => 'urban_restaurant_general',
        'settings' => 'urban_restaurant_post_readdmore_toggle_switch_control',
        'type'     => 'checkbox',
    ) ) );


}
add_action( 'customize_register', 'urban_restaurant_customize_register' );



